// Importing required modules
import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';
// Iris dataset
const csvUrl = [
  'https://gist.githubusercontent.com/vidhyanamini/e8ac1b7bf3c03930d4e7816edcb4ea64/raw/4802ec21e1a5ca977d05923b186a839bf16bd718/irisdataset.csv', // File name
].join('');
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);



const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
  	.symbolValue((d) => d.species)
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(5)
  	;

  svg.call(plot);
// Setting the dynamic  xaxis
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 15000);
};
main();



